@@ -3,7 +3,7 @@
  * plugins/forced_prefs/config-sample.php -- Sample configuration
  *
  * SquirrelMail Forced Prefs Plugin
- * Copyright (C) 2004 Tomas Kuliavas <tokul@users.sourceforge.net>
+ * Copyright (C) 2004-2005 Tomas Kuliavas <tokul@users.sourceforge.net>
  * This program is licensed under GPL. See COPYING for details
  *
  * plugin needs two variables that provide arrays with added ($fp_added_settings 
@@ -11,8 +11,8 @@
  *
  * Each variable is set with
  * $variable_name = array(
- *	'sm_user_setting1_name' => 'sm_user_setting1_value',
- *	'sm_user_setting2_name' => 'sm_user_setting2_value'
+ *  'sm_user_setting1_name' => 'sm_user_setting1_value',
+ *  'sm_user_setting2_name' => 'sm_user_setting2_value'
  * }
  *
  * name => value array pairs are separated with commas.
@@ -22,8 +22,8 @@
  * array that allows adding missing values
  */
 $fp_added_settings = array(
-    'hour_format'	=> '1',
-    'show_num'		=> '20'
+    'hour_format'   => '1',
+    'show_num'      => '20'
 );
 
 /**
@@ -32,4 +32,8 @@ $fp_added_settings = array(
 $fp_forced_settings = array(
     'show_html_default' => '1'
 );
-?>
+/**
+ * array that stores disabled hook function calls
+ */
+$fp_disabled_hooks = array('fortune_options','abook_take_options','bug_report_options');
+?>
\ No newline at end of file
